const canElideFrames$1 = 'captureStackTrace' in Error;
const startStackFrames$1 = new WeakMap();
class AssertionError$1 extends Error {
    constructor(message = 'Unspecified AssertionError', props, ssf) {
        super(message);
        this.message = message;
        if (canElideFrames$1 && ssf)
            startStackFrames$1.set(this, ssf);
        for (const key in props) {
            if (!(key in this)) {
                this[key] = props[key];
            }
        }
    }
    get name() {
        return 'AssertionError';
    }
    get ok() {
        return false;
    }
    get stack() {
        if (canElideFrames$1) {
            return Error.captureStackTrace(this, startStackFrames$1.get(this) || AssertionError$1);
        }
        else {
            return super.stack;
        }
    }
    toJSON(stack) {
        return Object.assign(Object.assign({}, this), { name: this.name, message: this.message, ok: false, stack: stack !== false ? this.stack : undefined });
    }
}

const canElideFrames = 'captureStackTrace' in Error;
const startStackFrames = new WeakMap();
class AssertionError extends Error {
    constructor(message = 'Unspecified AssertionError', props, ssf) {
        super(message);
        this.message = message;
        if (canElideFrames && ssf)
            startStackFrames.set(this, ssf);
        for (const key in props) {
            if (!(key in this)) {
                this[key] = props[key];
            }
        }
    }
    get name() {
        return 'AssertionError';
    }
    get ok() {
        return false;
    }
    get stack() {
        if (canElideFrames) {
            return Error.captureStackTrace(this, startStackFrames.get(this) || AssertionError);
        }
        else {
            return super.stack;
        }
    }
    toJSON(stack) {
        return Object.assign(Object.assign({}, this), { name: this.name, message: this.message, ok: false, stack: stack !== false ? this.stack : undefined });
    }
}

function assert(expr, msg) {
    if (!expr) {
        throw new AssertionError(msg || 'Assertion Failed');
    }
}
function not(expr, msg) {
    assert(!expr, msg);
}
function fail(msg) {
    assert(false, msg);
}

function err (fn, msg) {
  var thrown = false;
  try {
    fn();
  } catch (ex) {
    thrown = true;

    if (msg && msg !== ex.message) {
      var report = 'Expected "' + ex.message + '" to equal "' + msg + '".';
      throw new AssertionError$1(report);
    }
  }

  if (!thrown) {
    throw new AssertionError$1('Expected an error.');
  }
}

it('assert(expr)', function () {
  assert('string', 'string');

  assert(true, 'true');
  err(function () {
    assert(false, 'test message');
  }, 'test message');

  assert(1, '1');
  err(function () {
    assert(0, 'test message');
  }, 'test message');

  err(function () {
    assert(null, 'test message');
  }, 'test message');

  err(function () {
    assert(undefined, 'test message');
  }, 'test message');
});

it('not(expr)', function () {
  not(false, 'false');
  err(function () {
    not(true, 'test message');
  }, 'test message');

  not(0, '0');
  err(function () {
    not(1, 'test message');
  }, 'test message');

  not(null, 'null');
  not(undefined, 'undefined');
  err(function () {
    not('string', 'test message');
  }, 'test message');
});

it('fail(msg)', function () {
  err(function () {
    fail('test message');
  }, 'test message');
});
